/**
 * Reading Progress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 * @encoding     UTF-8
 * @version      2.0.0
 * @copyright    Copyright (C) 2016 - 2021 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

( function ( $ ) {

    "use strict";

    /** Run as soon as the page DOM becomes safe to manipulate. */
    $( document ).ready( function () {

        /** Position hidden input. */
        let $positionEl = $( '#t42_reading_progress_general_settings-position' );
        let position = $positionEl.val();

        /** Save Changes button. */
        let $saveBtn = $( '.t42-save-settings-btn' );

        /** Enable current Position button on page loading. */
        if ( position ) {
            $( '.t42-position-btn.t42-button-primary' ).removeClass( 't42-button-primary' ).addClass( 't42-button-default');
            $( '.t42-position-btn[data-position="' + position + '"]' ).removeClass( 't42-button-default' ).addClass( 't42-button-primary' );
        }

        /** Set Top/Bottom position. */
        $( '.t42-position-btn' ).on( 'click', SetPositionValue );

        /**
         * Set position value in hidden input.
         **/
        function SetPositionValue( event ) {

            event.preventDefault();

            let position = $( this ).data( 'position' );

            /** Set position value to hidden input. */
            $positionEl.val( position );

            /** Deactivate active position button. */
            $( '.t42-position-btn.t42-button-primary' ).removeClass( 't42-button-primary' ).addClass( 't42-button-default');

            /** Activate position button that was just pressed. */
            $( '.t42-position-btn[data-position="' + position + '"]' ).removeClass( 't42-button-default' ).addClass( 't42-button-primary' );

            /** Enable "Save Changes" button. */
            $saveBtn.prop( 'disabled', false ).addClass( 't42-unsaved' );

        }

        let $style = $( '#t42_reading_progress_general_settings-style' );
        let $backgroundColor = $( '#t42_reading_progress_general_settings-color' );
        let $backgroundGradient = $( '#t42_reading_progress_general_settings-color_gradient' );
        let $backgroundSwitcher = $( '#t42_reading_progress_general_settings-color_switcher' );

        let $shadowColor      = $( '#t42_reading_progress_general_settings-shadow_color' );
        let $shadowHorizontal = $( '#t42_reading_progress_general_settings-shadow_horizontal' );
        let $shadowVertical   = $( '#t42_reading_progress_general_settings-shadow_vertical' );
        let $shadowBlur       = $( '#t42_reading_progress_general_settings-shadow_blur' );
        let $shadowSpread     = $( '#t42_reading_progress_general_settings-shadow_spread' );
        let $shadowPosition   = $( '#t42_reading_progress_general_settings-shadow_position' );

        let $height = $( '#t42_reading_progress_general_settings-height' );

        /**
         * Refresh preview progress settings.
         **/
        function refreshPreview() {

            /** Get progress bar Style. */
            let style = $style.val();

            /** Get background color or gradient. */
            let background = $backgroundColor.val();
            if ( $backgroundSwitcher.is( ':checked' ) ) {
                background = $backgroundGradient.val();
            }

            /** Get box-shadow. */
            let shadow = '';
            if ( '1' === $( '#t42_reading_progress_general_settings-shadow_active' ).val() ) {

                let color      = $shadowColor.val();
                let horizontal = $shadowHorizontal.val();
                let vertical   = $shadowVertical.val();
                let blur       = $shadowBlur.val();
                let spread     = $shadowSpread.val();
                let position   = $shadowPosition.val();

                shadow = `${horizontal}px ${vertical}px ${blur}px ${spread}px ${color} ${position}`;

            }

            /** Get progress height. */
            let height = $height.val();

            /** Preview Progress Bar element. */
            let $progress = $( '#t42-reading-progress' );

            /** Set new values to preview progress bar */
            $progress.parent().removeClass().addClass( 't42-style-' + style );
            $progress.css( { background: background } );
            $progress.css( { boxShadow: shadow } );
            $progress.css( { height: height + 'px' } );

        }
        refreshPreview();

        /** Refresh preview on eny change. */
        $style.add( $backgroundColor )
              .add( $backgroundGradient )
              .add( $backgroundSwitcher )
              .add( $shadowColor )
              .add( $shadowHorizontal )
              .add( $shadowVertical )
              .add( $shadowBlur )
              .add( $shadowSpread )
              .add( $shadowPosition )
              .add( $height )
              .on( 'change', refreshPreview );

        /** Disable "Save Changes" button. */
        $saveBtn.prop( 'disabled', true ).removeClass( 't42-unsaved' );

    } );

} ( jQuery ) );