<?php
/**
 * Reading Progress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 * @encoding     UTF-8
 * @version      2.0.0
 * @copyright    Copyright (C) 2016 - 2021 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

namespace T42\ReadingProgress;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit;
}

/**
 * Load JS for Frontend Area.
 *
 * @since 2.0.0
 * @author Alexander Khmelnitskiy
 **/
final class FrontScripts extends Assets {

    use Singleton;

	/**
	 * Sets up a new FrontScripts instance.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return void
	 **/
	private function __construct() {

		/** CSS for frontend. */
		add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_scripts' ] );

	}

	/**
	 * Add JS for frontend area.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return void
	 **/
	public function enqueue_scripts() {

		/** Checks if plugin should work on this page. */
		if ( ! TabAssignments::get_instance()->display() ) { return; }

		/** Disable Reading Progress for Elementor and DIVI editor in the backend. */
        /** @noinspection NullPointerExceptionInspection */
        if ( Sense::get_instance()->is_page_builder() ) { return; }

		/** Enqueue Reading Progress script. */
		$this->enqueue_script( 'scrollProgress' );

        /** Shorthand for plugin settings. */
        $options = Settings::get_instance()->options;

        /** Prepare values to pass to JS. */
        $to_js = [
            'style'     => $options['style'],
            'color'     => $this->get_color(),
            'height'    => $options['height'],
            'position'  => $options['position'],
            'offset'    => $options['offset'],
            'selector'  => $options['selector'],
        ];
        wp_localize_script( $this->get_handle( 'scrollProgress' ), 't42ReadingProgressOptions', $to_js );

	}

    /**
     * Return color or gradient from gradient piker field.
     *
     * @since 2.0.0
     * @access public
     *
     * @return string
     **/
	private function get_color() {

        /** Shorthand for plugin settings. */
        $options = Settings::get_instance()->options;

        if ( 'on' === $options['color_switcher'] ) {

            return $options['color_gradient'];

        }

        return $options['color'];

    }

} // End class FrontScripts.
