<?php
/**
 * Reading Progress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 * @encoding     UTF-8
 * @version      2.0.0
 * @copyright    Copyright (C) 2016 - 2021 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

namespace T42\ReadingProgress;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit;
}

/**
 * Load CSS for Frontend Area.
 *
 * @since 2.0.0
 * @author Alexander Khmelnitskiy
 **/
final class FrontStyles extends Assets {

    use Singleton;

	/**
	 * Sets up a new FrontStyles instance.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return void
	 **/
	private function __construct() {

		/** CSS for frontend. */
		add_action( 'wp_enqueue_scripts', [ $this, 'enqueue_styles' ] );

	}

	/**
	 * Add CSS for frontend area.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return void
	 **/
	public function enqueue_styles() {

		/** Checks if plugin should work on this page. */
		if ( ! TabAssignments::get_instance()->display() ) { return; }

		/** Disable Reading Progress for Elementor and DIVI editor in the backend. */
        /** @noinspection NullPointerExceptionInspection */
        if ( Sense::get_instance()->is_page_builder() ) { return; }

		/** Enqueue Reading Progress style. */
		$this->enqueue_style( 'reading-progress' );

        /** Add inline styles. */
        wp_add_inline_style(
            $this->get_handle( 'reading-progress' ),
            $this->get_inline_styles()
        );

	}

    /**
     * Return inline CSS custom scrollbar.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string CSS
     **/
    private function get_inline_styles() {

        /** Short hand for plugin options. */
        $options = Settings::get_instance()->options;

        /** Resulting CSS. */
        $css = '';

        /** If Box Shadow is enabled */
        if ( '1' === $options['shadow']['active'] ) {

            $color      = $options['shadow']['color'];
            $horizontal = $options['shadow']['horizontal'];
            $vertical   = $options['shadow']['vertical'];
            $blur       = $options['shadow']['blur'];
            $spread     = $options['shadow']['spread'];
            $position   = $options['shadow']['position'];

            // language=CSS
            $css .= "
                /*noinspection ALL*/
                #t42-reading-progress {
                    box-shadow:  {$horizontal}px {$vertical}px {$blur}px {$spread}px $color $position;                
                }
            ";

        }

        /** Add user's custom CSS from plugin settings. */
        $css .= $options['custom_css'];

        return $css;

    }

} // End class FrontStyles.
