<?php
/**
 * Reading Progress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 * @encoding     UTF-8
 * @version      2.0.0
 * @copyright    Copyright (C) 2016 - 2021 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

namespace T42\ReadingProgress;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit;
}

/**
 * SINGLETON: The class contains main plugin logic.
 *
 * @since 2.0.0
 * @author Alexander Khmelnitskiy
 **/
final class Sense {

    use Singleton;

	/**
	 * Setup the plugin.
	 *
	 * @since 2.0.0
	 * @access public
	 *
	 * @return void
	 **/
	public function setup() {

		/** Define hooks that runs on both the front-end as well as the dashboard. */
		$this->both_hooks();

		/** Define public hooks. */
		$this->public_hooks();

		/** Define admin hooks. */
		$this->admin_hooks();

	}

	/**
	 * Define hooks that runs on both the front-end as well as the dashboard.
	 *
	 * @since 2.0.0
	 * @access private
	 *
	 * @return void
	 **/
	private function both_hooks() {

		/** Hooks which should work everywhere in backend and frontend. */

	}

	/**
	 * Register all of the hooks related to the public-facing functionality.
	 *
	 * @since 2.0.0
	 * @access private
	 *
	 * @return void
	 **/
	private function public_hooks() {

		/** Work only on frontend area. */
		if ( is_admin() ) { return; }

        /** Add frontend CSS. */
        FrontStyles::get_instance();

        /** Add frontend JS. */
        FrontScripts::get_instance();

	}

	/**
	 * Register all of the hooks related to the admin area functionality.
	 *
	 * @since 2.0.0
	 * @access private
	 *
	 * @return void
	 **/
	private function admin_hooks() {

		/** Work only in admin area. */
		if ( ! is_admin() ) { return; }

	}

    /**
     * Is page builder in admin?
     *
     * Check if we are in one of the page builders, in editor mode on the front-end.
     *
     * @since 2.0.0
     * @access public
     *
     * @return bool True if this is Elementor or DIVI builder, False otherwise.
     **/
    public function is_page_builder() {

        /** Elementor builder preview. */
        if ( isset( $_GET['elementor-preview'] ) ) { return true; }

        /** DIVI builder on front-end. */
        if ( isset( $_GET['et_fb'] ) ) { return true; }

        return false;

    }

} // End Class Sense.
